from django.http import HttpResponse, HttpResponseBadRequest
from django.shortcuts import redirect
from django.shortcuts import get_list_or_404
from django.shortcuts import get_object_or_404
from core.models import Host, Installation


def add_host(request):
    if not request.method == 'POST':
        return HttpResponseBadRequest(content='Request method should be POST')

    hostname = request.POST.get('hostname')

    host, created = Host.objects.get_or_create(hostname=hostname)

    host.mac = request.POST.get('mac')
    host.disk_count = request.POST.get('disk_count')
    host.ipmi_host = request.POST.get('ipmi_host')
    host.ipmi_user = request.POST.get('ipmi_user')
    host.ipmi_pass = request.POST.get('ipmi_pass')

    if not created:
        list = Installation.objects.exclude(status='ready') \
            .exclude(status='abort')
        for installation in list:
            installation.abort()
    host.save()

    return redirect('/')


def delete_host(request):
    if not request.method == 'POST':
        return HttpResponseBadRequest(content='Request method should be POST')

    hosts = get_list_or_404(Host, pk__in=request.POST.getlist('hosts[]'))
    for host in hosts:
        host.delete()
    return redirect('/')


def apply_profile(request):
    if not request.method == 'POST':
        return HttpResponseBadRequest(content='Request method should be POST')
    hosts = get_list_or_404(Host, pk__in=request.POST.getlist('hosts[]'))
    profile = request.POST.get('profile')
    for host in hosts:
        install = Installation.create(host=host, profile=profile)
        install.create_files()
        install.status = 'pending_installation'
        install.save()
    return redirect('/')


def preseed(request, token):
    install = Installation.objects.get(hash=token)
    if not ('preview' in request.GET):
        install.status = 'installing'
        install.delete_pxe()
        install.save()
    return HttpResponse(
        content=install.install_conf,
        content_type='text/plain'
    )


def firstboot(request, token):
    install = Installation.objects.get(hash=token)
    install.status = 'configuring'
    install.save()
    return HttpResponse(
        content=install.first_boot,
        content_type='text/plain')


def firstboot_checkpoint(request, token, checkpoint):
    install = get_object_or_404(Installation, hash=token)
    if checkpoint == 'checkpoint':
        install.status = 'configuring'
    elif checkpoint == 'done':
        install.status = 'done'
    elif checkpoint == 'error':
        install.status = 'error'
    install.save()
    return HttpResponse(content='ok', content_type='text/plain')
